Estimate the oracle bias, the oracle variance of the unadjusted estimator, the adjusted estimator by Lei’s (2020) and the debiased estimator tau_db by Lu et al.(2023).
get_oracle_bias_var_adj_db(X, Y1, n1 = NULL)A list of the oracle bias and variance of .
The oracle bias of the adjusted estimator tau_adj we proposed.
The oracle variance of the unadjusted estimator.
The oracle variance of Lei’s (2020) debiased estimator with linear working model.
The oracle variance of the debiased estimator tau_db by Lu et al.(2023).
The n by p covariates matrix.
Vector of n dimensional potential response Y(1).
The number of subjects in the treatment group.
Lihua Lei, Peng Ding. Regression adjustment in completely randomized experiments with a diverging number of covariates. Biometrika, 815–828, 2020.
Xin Lu, Fan Yang, and Yuhao Wang. Debiased regression adjustment in completely randomized experiments with moderately high-dimensional covariates. arXiv preprint arXiv:2309.02073, 2023.